@@ -8,7 +8,7 @@ use List::MoreUtils qw/zip/;
 use Carp qw/croak/;
 use Class::Load qw/load_class/;
 
-our $VERSION = '1.001'; # VERSION
+our $VERSION = '1.002'; # VERSION
 
 has _sth => (
     is       => 'ro',
@@ -87,12 +87,12 @@ sub object {
     my ($self, $class, @args) = @_;
     $class = __PACKAGE__ . ":$class" if $class =~ /^:/;
     load_class($class);
-    if ($class->can('new_from_dbix_simpler')) {
-        return scalar $class->new_from_dbix_simpler($self, @args)
+    if ($class->can('new_from_dbix_simplish')) {
+        return scalar $class->new_from_dbix_simplish($self, @args)
     } elsif ($class->can('new')) {
         return $class->new($self->kv_list);
     } else {
-        croak(q/Can't locate object method "new_from_dbix_simpler" or "new"/);
+        croak(q/Can't locate object method "new_from_dbix_simplish" or "new"/);
     }
 }
 
@@ -136,14 +136,14 @@ sub objects {
     my ($self, $class, @args) = @_;
     $class = __PACKAGE__ . ":$class" if $class =~ /^:/;
     load_class($class);
-    if ($class->can('new_from_dbix_simpler')) {
-        my @objects = $class->new_from_dbix_simpler($self, @args);
+    if ($class->can('new_from_dbix_simplish')) {
+        my @objects = $class->new_from_dbix_simplish($self, @args);
         return wantarray ? @objects : \@objects;
     } elsif ($class->can('new')) {
         my @objects = map  {$class->new(@{$_})} $self->kv_arrays;
         return wantarray ? @objects : \@objects;
     } else {
-        croak(q/Can't locate object method "new_from_dbix_simpler" or "new"/);
+        croak(q/Can't locate object method "new_from_dbix_simplish" or "new"/);
     }
 }
 
@@ -188,7 +188,7 @@ DBIx::Simplish::Result - A result of a L<DBIx::Simplish> query.
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
